## START: Set by rpmautospec
## (rpmautospec version 0.8.2)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 3;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Switch to clang by default
%bcond          gcc 0

Name:           ispc
Version:        1.27.0
Release:        %autorelease
Summary:        C-based SPMD programming language compiler
License:        BSD-3-Clause
URL:            https://ispc.github.io/
Source0:        https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  clang-devel
BuildRequires:  flex 
%if %{with gcc}
BuildRequires:  gcc-c++
%endif
BuildRequires:  llvm-devel
BuildRequires:  pkgconfig(python3)
%ifarch x86_64
# Koji 64-bit buildroots do not contain packages from 32-bit builds, therefore
# the 'glibc-devel.i686' variant is provided as 'glibc32'.
BuildRequires:  (glibc32 or glibc-devel(%__isa_name-32))
BuildRequires:  oneapi-level-zero-devel
%endif
BuildRequires:  pkgconfig(tbb)

# Upstream only supports these architectures
ExclusiveArch:  x86_64 aarch64

%description
A compiler for a variant of the C programming language, with extensions for
"single program, multiple data" (SPMD) programming.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
applications that use %{name}.

%package        static
Summary:        Static libraries for %{name} development
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}

%description    static
The %{name}-static package includes static libraries needed
to develop programs that use %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}

# Delete unrecognized command options from gcc-c++
sed -i 's|-Wno-c99-extensions -Wno-deprecated-register||g' CMakeLists.txt

# Fix all Python shebangs recursively in .
%py3_shebang_fix .

%build
%cmake \
        -DCMAKE_BUILD_TYPE=Release \
%if %{with gcc}
        -DCMAKE_C_COMPILER=gcc \
        -DCMAKE_CXX_COMPILER=g++ \
%endif
        -DCMAKE_EXE_LINKER_FLAGS="%{optflags} -fPIE" \
        -DISPC_INCLUDE_EXAMPLES=OFF \
        -DISPC_INCLUDE_TESTS=ON \
%ifarch x86_64
        -DLEVEL_ZERO_INCLUDE_DIR=%{_includedir} \
        -DLEVEL_ZERO_LIB_LOADER=%{_libdir}/libze_loader.so.1 \
        -DISPCRT_BUILD_CPU=ON \
        -DISPCRT_BUILD_GPU=ON \
        -DISPCRT_BUILD_TESTS=OFF \
%endif
        -DLLVM_ENABLE_ASSERTIONS=OFF
%cmake_build

%install
%cmake_install

%check
PATH="${PATH}:%{buildroot}%{_bindir}" %{python3} scripts/run_tests.py

%files
%license LICENSE.txt
%doc docs/ReleaseNotes.txt
%{_bindir}/%{name}
%{_bindir}/check_isa
%{_libdir}/lib%{name}rt.so.{1,%{version}}
%{_libdir}/lib%{name}rt_device_cpu.so.{1,%{version}}
%ifarch x86_64
%{_libdir}/lib%{name}rt_device_gpu.so.{1,%{version}}
%endif

%files devel
%doc docs/ReleaseNotes.txt
%{_includedir}/%{name}rt/
%{_libdir}/cmake/%{name}rt-%{version}/
%{_libdir}/lib%{name}rt.so
%{_libdir}/lib%{name}rt_device_cpu.so
%ifarch x86_64
%{_libdir}/lib%{name}rt_device_gpu.so
%endif

%files static
%license LICENSE.txt
%doc docs/ReleaseNotes.txt
%{_libdir}/lib%{name}rt_static.a

%changelog
## START: Generated by rpmautospec
* Thu Jul 24 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.27.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_43_Mass_Rebuild

* Thu Jul 10 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1.27.0-2
- Switch compiler to clang by default

* Fri May 16 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1.27.0-1
- Update to 1.27.0 (rhbz#2344092)

* Fri Jan 17 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.25.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Tue Nov 19 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1.25.3-2
- Rebuild for oneapi-level-zero 1.19.0

* Thu Nov 14 2024 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 1.25.3-1
- Update to 1.25.3 (rhbz#2324512)

* Tue Nov 05 2024 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 1.25.2-1
- Update to 1.25.2 (rhbz#2319500)

* Wed Oct 16 2024 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 1.25.0-2
- aarch64 test fixes

* Wed Oct 16 2024 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 1.25.0-1
- Update to 1.25.0 (rhbz#2318717)

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.24.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Tue May 28 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1.24.0-1
- Update to 1.24.0 (rhbz#2283117)

* Fri Feb 16 2024 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 1.23.0-1
- Update to 1.23.0

* Sat Feb 03 2024 Jan Kolarik <jkolarik@redhat.com> - 1.22.0-5
- Don't build-require files outside of permitted directories

* Wed Jan 24 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.22.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sat Jan 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.22.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 17 2024 Jonathan Wakely <jwakely@redhat.com> - 1.22.0-2
- Rebuilt for TBB 2021.11

* Tue Nov 21 2023 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 1.22.0-1
- Update to 1.22.0

* Tue Oct 17 2023 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 1.21.1-1
- update to 1.21.1 (rhbz #2243038)

* Tue Oct 10 2023 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 1.21.0-2
- missing requires added for static package

* Sat Aug 19 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1.21.0-1
- Update to 1.21.0 (rhbz#2195967)

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.19.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sat Mar 18 2023 aekoroglu <aekoroglu@linux.intel.com> - 1.19.0-4
- libispcrt_static.a needed for ospray

* Wed Mar 01 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1.19.0-3
- Update to 1.19.0

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.19.0-0.2.20230102gitec62d6c
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Jan 07 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1.19.0-0.1.20230102gitec62d6c
- New snapshot release fixing compatibility with LLVM 15

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.18.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sat May 07 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1.18.0-1
- Update to 1.18.0 (#2082710)

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.17.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Jan 15 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1.17.0-1
- Update to 1.17.0 (#2041039)

* Sun Aug 01 2021 Luya Tshimbalanga <luya@fedoraproject.org> 1.16.1-2
- Use autorelease and autochangelog macros
- Resolves rhbz#1983136

* Fri Jul 16 2021 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 1.16.1-1
- Update to 1.16.1 (#1983136)

* Sat Jun 12 2021 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 1.16.0-1
- Update to 1.16.0 (#1971133)
- Resolves rhbz#1971133

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 22 2021 Tom Stellard <tstellar@redhat.com> - 1.15.0-2
- Rebuild for clang-11.1.0

* Sat Dec 19 2020 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 1.15.0-1
- Update to 1.15.0 (#1909333)

* Sat Oct 31 2020 Luya Tshimbalanga <luya@fedoraproject.org> - 1.14.1-2
- Rebuild for llvm 11

* Sat Aug 29 2020 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 1.14.1-1
- Update to 1.14.1 (#1862505)

* Sat Aug 01 2020 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 1.14.0-1
- Update to 1.14.0 (#1862505)

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.13.0-4
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.13.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jun 09 2020 Luya Tshimbalanga <luya@fedoraproject.org> - 1.13.0-2
- Exclude i686 architecture

* Fri Apr 24 2020 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 1.13.0-1
- Update to 1.13.0 (#1827516)
- Disable warning treated as error message
- Only exclude ppc64le and s390x architectures



## END: Generated by rpmautospec
